//// [tests/cases/compiler/es6ImportDefaultBindingNoDefaultProperty.ts] ////

//// [es6ImportDefaultBindingNoDefaultProperty_0.ts]

export var a = 10;

//// [es6ImportDefaultBindingNoDefaultProperty_1.ts]
import defaultBinding from "./es6ImportDefaultBindingNoDefaultProperty_0";


//// [es6ImportDefaultBindingNoDefaultProperty_0.js]
exports.a = 10;
//// [es6ImportDefaultBindingNoDefaultProperty_1.js]
